@@ -12,6 +12,8 @@ configtools
 The ``guidata.configtools`` module provides configuration related tools.
 """
 
+from __future__ import print_function
+
 import os
 import os.path as osp
 import sys
@@ -21,7 +23,9 @@ from guidata.qt.QtGui import (QFont, QLabel, QPixmap, QIcon, QHBoxLayout,
                               QColor, QPen, QBrush, QFontDatabase)
 from guidata.qt.QtCore import Qt
 
-from guidata.utils import get_module_path
+from guidata.utils import get_module_path, decode_fs_string
+
+from guidata.py3compat import is_unicode, to_text_string, PY3, is_text_string
 
 IMG_PATH = []
 
@@ -48,7 +52,7 @@ def get_translation(modname, dirname=None):
         dirname = modname
     # fixup environment var LANG in case it's unknown
     if "LANG" not in os.environ:
-        import locale
+        import locale # Warning: 2to3 false alarm ('import' fixer)
         lang = locale.getdefaultlocale()[0]
         if lang is not None:
             os.environ["LANG"] = lang
@@ -57,15 +61,19 @@ def get_translation(modname, dirname=None):
                                      codeset="utf-8")
         lgettext = _trans.lgettext
         def translate_gettext(x):
-            if isinstance(x, unicode):
+            if not PY3 and is_unicode(x):
                 x = x.encode("utf-8")
-            return unicode(lgettext(x), "utf-8")
+            y = lgettext(x)
+            if is_text_string(y) and PY3:
+                return y
+            else:
+                return to_text_string(y, "utf-8")
         return translate_gettext
-    except IOError, _e:
+    except IOError as _e:
         #print "Not using translations (%s)" % _e
         def translate_dumb(x):
-            if not isinstance(x, unicode):
-                return unicode(x, "utf-8")
+            if not is_unicode(x):
+                return to_text_string(x, "utf-8")
             return x
         return translate_dumb
 
@@ -78,6 +86,8 @@ def get_module_locale_path(modname):
 
 def add_image_path(path, subfolders=True):
     """Append image path (opt. with its subfolders) to global list IMG_PATH"""
+    if not is_unicode(path):
+        path = decode_fs_string(path)
     global IMG_PATH
     IMG_PATH.append(path)
     if subfolders:
@@ -153,10 +163,9 @@ def get_image_layout(imagename, text="", tooltip="", alignment=Qt.AlignLeft):
 
 
 def font_is_installed(font):
-    """
-    Check if font is installed
-    """
-    return [fam for fam in QFontDatabase().families() if unicode(fam)==font]
+    """Check if font is installed"""
+    return [fam for fam in QFontDatabase().families()
+            if to_text_string(fam)==font]
 
 
 MONOSPACE = ['Courier New', 'Bitstream Vera Sans Mono', 'Andale Mono',
@@ -171,7 +180,7 @@ def get_family(families):
         if font_is_installed(family):
             return family
     else:
-        print "Warning: None of the following fonts is installed: %r" % families
+        print("Warning: None of the following fonts is installed: %r" % families)
         return ""
 
 
