@@ -13,13 +13,17 @@ The ``guidata.dataset.dataitems`` module contains implementation for
 concrete DataItems.
 """
 
-from __future__ import division
+from __future__ import division, unicode_literals
 
-import os, re, datetime
+import os
+import re
+import datetime
+import collections
 
 from guidata.dataset.datatypes import DataItem, ItemProperty
 from guidata.utils import utf8_to_unicode, add_extension
 from guidata.config import _
+from guidata.py3compat import to_text_string, is_text_string, TEXT_TYPES
 
 
 class NumericTypeItem(DataItem):
@@ -80,7 +84,7 @@ class NumericTypeItem(DataItem):
 
     def from_string(self, value):
         """Override DataItem method"""
-        value = unicode(value) # necessary if value is a QString
+        value = to_text_string(value) # necessary if value is a QString
         # String may contains numerical operands:
         if re.match(r'^([\d\(\)\+/\-\*.]|e)+$', value):
             try:
@@ -179,7 +183,7 @@ class StringItem(DataItem):
         * notempty [bool]: if True, empty string is not a valid value (opt.)
         * wordwrap [bool]: toggle word wrapping (optional)
     """
-    type = (unicode, str)
+    type = TEXT_TYPES
     def __init__(self, label, default=None, notempty=None,
                  wordwrap=False, help=''):
         DataItem.__init__(self, label, default=default, help=help)
@@ -196,7 +200,7 @@ class StringItem(DataItem):
     def from_string(self, value):
         """Override DataItem method"""
         # QString -> str
-        return unicode(value)
+        return to_text_string(value)
 
     def get_value_from_reader(self, reader):
         """Reads value from the reader object, inside the try...except 
@@ -214,7 +218,7 @@ class TextItem(StringItem):
         * wordwrap [bool]: toggle word wrapping (optional)
     """
     def __init__(self, label, default=None, notempty=None,
-                 wordwrap=True,help=''):
+                 wordwrap=True, help=''):
         StringItem.__init__(self, label, default=default, notempty=notempty,
                             wordwrap=wordwrap, help=help)
 
@@ -340,7 +344,7 @@ class FilesOpenItem(FileSaveItem):
     type = list
     def __init__(self, label, formats='*', default=None,
                  basedir=None, all_files_first=False, help=''):
-        if isinstance(default, (unicode, str)):
+        if is_text_string(default):
             default = [default]
         FileSaveItem.__init__(self, label, formats=formats,
                               default=default, basedir=basedir,
@@ -356,7 +360,7 @@ class FilesOpenItem(FileSaveItem):
 
     def from_string(self, value):        
         """Override DataItem method"""
-        value = unicode(value)
+        value = to_text_string(value)
         if value.endswith("']"):
             value = eval(value)
         else:
@@ -371,7 +375,8 @@ class FilesOpenItem(FileSaveItem):
     def get_value_from_reader(self, reader):
         """Reads value from the reader object, inside the try...except 
         statement defined in the base item `deserialize` method"""
-        return [unicode(fname, "utf-8") for fname in reader.read_sequence()]
+        return [to_text_string(fname, "utf-8")
+                for fname in reader.read_sequence()]
 
 
 class DirectoryItem(StringItem):
@@ -403,13 +408,14 @@ class ChoiceItem(DataItem):
         * help [string]: text shown in tooltip (optional)
     """
     def __init__(self, label, choices, default=FirstChoice, help=''):
-        if callable(choices):
+        if isinstance(choices, collections.Callable):
             _choices_data = ItemProperty(choices)
         else:
             _choices_data = []
             for idx, choice in enumerate(choices):
                 _choices_data.append( self._normalize_choice(idx, choice) )
-        if default is FirstChoice and not callable(choices):
+        if default is FirstChoice and\
+           not isinstance(choices, collections.Callable):
             default = _choices_data[0][0]
         elif default is FirstChoice:
             default = None
@@ -423,7 +429,7 @@ class ChoiceItem(DataItem):
             key = idx
             value = choice_tuple
 
-        if isinstance(value,str):
+        if isinstance(value, str):
             value = utf8_to_unicode(value)
         return (key, value, None)
             
@@ -440,7 +446,7 @@ class ChoiceItem(DataItem):
         #print "ShowChoiceWidget:", choices, value
         for choice in choices:
             if choice[0] == value:
-                return unicode(choice[1])
+                return to_text_string(choice[1])
         else:
             return DataItem.get_string_value(self, instance)
         
@@ -544,20 +550,21 @@ class FloatArrayItem(DataItem):
     def format_string(self, instance, value, fmt, func):
         """Override DataItem method"""
         larg = self.get_prop_value("display", instance, "large", False)
-        fmt = self.get_prop_value("display", instance, "format", u"%s")
+        fmt = self.get_prop_value("display", instance, "format", "%s")
+        unit = self.get_prop_value("display", instance, "unit", "")
         v = func(value)        
         if larg:
-            text = u"= ["
+            text = "= ["
             for flt in v[:-1]:
                 text += fmt % flt + "; "
             text += fmt % v[-1] + "]"
-            return unicode(text)
         else:
-            text = u"~= " + fmt % v.mean()
+            text = "~= " + fmt % v.mean()
             text += " [" + fmt % v.min()
             text += " .. " + fmt % v.max()
-            text += "]"
-            return unicode(text)
+            text += "]"            
+        text += " %s" % unit
+        return to_text_string(text)
 
     def serialize(self, instance, writer):
         """Serialize this item"""
