@@ -17,6 +17,8 @@ Dialog boxes used to edit data sets:
     DataSetShowLayout
 """
 
+from __future__ import print_function
+
 try:
     # PyQt4 4.3.3 on Windows (static DLLs) with py2exe installed:
     # -> pythoncom must be imported first, otherwise py2exe's boot_com_servers
@@ -35,6 +37,7 @@ from guidata.qt.compat import getopenfilename, getopenfilenames, getsavefilename
 
 from guidata.configtools import get_icon
 from guidata.config import _
+from guidata.py3compat import to_text_string, is_text_string
 
 from guidata.dataset.datatypes import (BeginGroup, EndGroup, GroupItem,
                                        TabGroupItem)
@@ -268,13 +271,13 @@ class DataSetEditLayout(object):
         item = widget.item
         line, col, span = self.items_pos[item.item]
         if col > 0:
-            self.layout.addItem( QSpacerItem(20, 1) , line, col*3-1 )
+            self.layout.addItem( QSpacerItem(20, 1), line, col*3-1 )
             
         widget.place_on_grid( self.layout, line, col*3, col*3 + 1, 1, 3*span-2)
         try:
             widget.get()
         except Exception:
-            print "Error building item :", item.item._name
+            print("Error building item :", item.item._name)
             raise
 
     def refresh_widgets(self):
@@ -480,7 +483,7 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
                 button_text = _("Apply")
             if button_icon is None:
                 button_icon = get_icon("apply.png")
-            elif isinstance(button_icon, basestring):
+            elif is_text_string(button_icon):
                 button_icon = get_icon(button_icon)
             apply_btn = QPushButton(button_icon, button_text, self)
             self.connect(apply_btn, SIGNAL("clicked()"), self.set)
@@ -503,5 +506,5 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
         """Return data item title combined with QApplication title"""
         app_name = QApplication.applicationName()
         if not app_name:
-            app_name = unicode(self.title())
+            app_name = to_text_string(self.title())
         return "%s - %s" % ( app_name, item.label() )
