@@ -10,9 +10,13 @@ Text visitor for DataItem objects
 (for test purpose only)
 """
 
+from __future__ import print_function
+
+from guidata.py3compat import input
+
 def prompt(item):
     """Get item value"""
-    return raw_input(item.get_prop("display","label")+" ? ")
+    return input(item.get_prop("display", "label")+" ? ")
 
 class TextEditVisitor:
     """Text visitor"""
@@ -26,7 +30,7 @@ class TextEditVisitor:
             item.set_from_string(self.instance, value)
             if item.check_item(self.instance):
                 break
-            print "Incorrect value!"
+            print("Incorrect value!")
 
     visit_FloatItem = visit_generic
     visit_IntItem = visit_generic
