@@ -9,7 +9,11 @@
 GUI-based test launcher
 """
 
-import sys, os, os.path as osp, subprocess
+import sys
+import os
+import os.path as osp
+import subprocess
+
 from spyderlib.widgets.sourcecode.codeeditor import CodeEditor
 
 # Local imports
@@ -60,6 +64,10 @@ class TestModule(object):
             return '<br>'.join(lines)
     
     def run(self, args=''):
+        # Keep the same sys.path environment in child process:
+        # (useful when the program is executed from Spyder, for example)
+        os.environ['PYTHONPATH'] = os.pathsep.join(sys.path)
+        
         command = [sys.executable, '"'+self.filename+'"']
         if args:
             command.append(args)
@@ -117,7 +125,7 @@ class TestLauncherWindow(QSplitter):
     def __init__(self, package, parent=None):
         QSplitter.__init__(self, parent)
         self.setWindowTitle(_("Tests - %s module") % package.__name__)
-        self.setWindowIcon(get_icon("%s.png" % package.__name__, "guidata.png"))
+        self.setWindowIcon(get_icon("%s.svg" % package.__name__, "guidata.svg"))
         
         test_package_name = '%s.tests' % package.__name__
         _temp = __import__(test_package_name)
