@@ -9,11 +9,18 @@
 Reader and Writer for the serialization of DataSets into HDF5 files
 """
 
+from __future__ import print_function
+
 import sys
+from uuid import uuid1
+
 import h5py
 import numpy as np
 
 from guidata.utils import utf8_to_unicode
+from guidata.userconfigio import BaseIOHandler, WriterMixin
+
+from guidata.py3compat import to_text_string, PY3, is_binary_string
 
 
 class TypeConverter(object):
@@ -28,13 +35,14 @@ class TypeConverter(object):
         try:
             return self._to_type(value)
         except:
-            print >>sys.stderr, "ERR", repr(value)
+            print("ERR", repr(value), file=sys.stderr)
             raise
 
     def from_hdf(self, value):
         return self._from_type(value)
 
 
+#TODO: Py3/Test if the 'unicode_hdf' type converter is working with Python 3
 unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), utf8_to_unicode)
 int_hdf = TypeConverter(int)
 
@@ -78,7 +86,7 @@ class Attr(object):
         try:
             group.attrs[self.hdf_name] = value
         except:
-            print >>sys.stderr, "ERROR saving:", repr(value), "into", self.hdf_name
+            print("ERROR saving:", repr(value), "into", self.hdf_name, file=sys.stderr)
             raise
     
     def load(self, group, struct):
@@ -90,13 +98,13 @@ class Attr(object):
         try:
             value = group.attrs[self.hdf_name]
         except KeyError:
-            raise KeyError, 'Unable to locate attribute %s' % self.hdf_name
+            raise KeyError('Unable to locate attribute %s' % self.hdf_name)
         if self.type is not None:
             value = self.type.from_hdf(value)
         self.set_value(struct, value)
 
 
-def createdset(group,name,value):
+def createdset(group, name, value):
     group.create_dataset(name,
                          compression=None,
                          #compression_opts=3,
@@ -135,7 +143,7 @@ class Dset(Attr):
         try:
             value = group[self.hdf_name][...]
         except KeyError:
-            raise KeyError, 'Unable to locate dataset %s' % self.hdf_name
+            raise KeyError('Unable to locate dataset %s' % self.hdf_name)
         if self.scalar is not None:
             value = self.scalar(value)
         self.set_value(struct, value)
@@ -149,6 +157,10 @@ class Dlist(Dset):
         setattr(struct, self.struct_name, list(value))
 
 
+#==============================================================================
+# Base HDF5 Store object: do not break API compatibility here as this class is 
+# used in various critical projects for saving/loading application data
+#==============================================================================
 class H5Store(object):
     def __init__(self, filename):
         self.filename = filename
@@ -159,9 +171,9 @@ class H5Store(object):
         if self.h5:
             return self.h5
         try:
-            self.h5 = h5py.File(self.filename,mode=mode)
+            self.h5 = h5py.File(self.filename, mode=mode)
         except Exception:
-            print >>sys.stderr, "Error trying to load:", self.filename, "in mode:", mode
+            print("Error trying to load:", self.filename, "in mode:", mode, file=sys.stderr)
             raise
         return self.h5
 
@@ -191,90 +203,132 @@ class H5Store(object):
             try:
                 instr.load(parent, dest)
             except Exception:
-                print >>sys.stderr, "Error loading HDF5 item:", instr.hdf_name
+                print("Error loading HDF5 item:", instr.hdf_name, file=sys.stderr)
                 raise
 
 
-class HDF5Writer(H5Store):
-    """Writer for HDF5 files"""
+#==============================================================================
+# HDF5 reader/writer: do not break API compatibility here as this class is 
+# used in various critical projects for saving/loading application data and 
+# in guiqwt for saving/loading plot items.
+#==============================================================================
+class HDF5Handler(H5Store, BaseIOHandler):
+    """Base HDF5 I/O Handler object"""
     def __init__(self, filename):
-        super(HDF5Writer, self).__init__(filename)
-        self.open("w")
+        H5Store.__init__(self, filename)
         self.option = []
         
     def get_parent_group(self):
         parent = self.h5
-        for p in self.option[:-1]:
-            parent = parent.require_group( p )
+        for option in self.option[:-1]:
+            parent = parent.require_group(option)
         return parent
 
+class HDF5Writer(HDF5Handler, WriterMixin):
+    """Writer for HDF5 files"""
+    def __init__(self, filename):
+        super(HDF5Writer, self).__init__(filename)
+        self.open("w")
+
     def write_any(self, val):
         group = self.get_parent_group()
         group.attrs[self.option[-1]] = val
-
-    def write_float(self, val):
-        group = self.get_parent_group()
-        group.attrs[self.option[-1]] = val
     
-    write_int = write_float
+    write_int = write_float = write_any
     
     def write_bool(self, val):
-        self.write_int( int(val))
+        self.write_int(int(val))
     
+    write_str = write_any
+
     def write_unicode(self, val):
         group = self.get_parent_group()
         group.attrs[self.option[-1]] = val.encode("utf-8")
+    if PY3:
+        write_unicode = write_str
 
     def write_array(self, val):
         group = self.get_parent_group()
         group[self.option[-1]] = val
     
     write_sequence = write_any
+    
     def write_none(self):
         group = self.get_parent_group()
         group.attrs[self.option[-1]] = ""
 
-    def begin(self, section):
-        self.option.append(section)
-        
-    def end(self, section):
-        sect = self.option.pop(-1)
-        assert sect == section
+    def write_object_list(self, seq, group_name):
+        """Write object sequence in group.
+        Objects must implement the DataSet-like `serialize` method"""
+        with self.group(group_name):
+            if seq is None:
+                self.write_none()
+            else:
+                ids = []
+                for obj in seq:
+                    guid = str(uuid1())
+                    ids.append(guid)
+                    with self.group(guid):
+                        if obj is None:
+                            self.write_none()
+                        else:
+                            obj.serialize(self)
+                self.write(ids, 'IDs')
 
-
-class HDF5Reader(H5Store):
-    """Writer for HDF5 files"""
+class HDF5Reader(HDF5Handler):
+    """Reader for HDF5 files"""
     def __init__(self, filename):
         super(HDF5Reader, self).__init__(filename)
         self.open("r")
-        self.option = []
-        
-    def get_parent_group(self):
-        parent = self.h5
-        for p in self.option[:-1]:
-            parent = parent.require_group( p )
-        return parent
+
+    def read(self, group_name=None, func=None, instance=None):
+        """Read value within current group or group_name.
+
+        Optional argument `instance` is an object which 
+        implements the DataSet-like `deserialize` method."""
+        if group_name:
+            self.begin(group_name)
+        if instance is None:
+            if func is None:
+                func = self.read_any
+            val = func()
+        else:
+            group = self.get_parent_group()
+            if group_name in group.attrs:
+                # This is an attribute (not a group), meaning that 
+                # the object was None when deserializing it
+                val = None
+            else:
+                instance.deserialize(self)
+                val = instance
+        if group_name:
+            self.end(group_name)
+        return val
 
     def read_any(self):
         group = self.get_parent_group()
-        print self.option
-        return group.attrs[self.option[-1]]
+        value = group.attrs[self.option[-1]]
+        if is_binary_string(value):
+            return value.decode("utf-8")
+        else:
+            return value
 
-    def begin(self, section):
-        self.option.append(section)
-        
-    def end(self, section):
-        sect = self.option.pop(-1)
-        assert sect == section
+    def read_bool(self):
+        val = self.read_any()
+        if val != '':
+            return bool(val)
 
     def read_int(self):
-        return int(self.read_any())
+        val = self.read_any()
+        if val != '':
+            return int(val)
 
     def read_float(self):
-        return float(self.read_any())
+        val = self.read_any()
+        if val != '':
+            return float(val)
 
-    def read_unicode(self):
-        return unicode(self.read_any(), "utf-8")
+    read_unicode = read_str = read_any
     
     def read_array(self):
         group = self.get_parent_group()
@@ -283,5 +337,30 @@ class HDF5Reader(H5Store):
     def read_sequence(self):
         group = self.get_parent_group()
         return list(group.attrs[self.option[-1]])
+    
+    def read_object_list(self, group_name, klass):
+        """Read object sequence in group.
+        Objects must implement the DataSet-like `deserialize` method.
+        `klass` is the object class which constructor requires no argument."""
+        with self.group(group_name):
+            try:
+                ids = self.read('IDs', func=self.read_sequence)
+            except ValueError:
+                # None was saved instead of list of objects
+                self.end('IDs')
+                return
+            seq = []
+            for name in ids:
+                with self.group(name):
+                    group = self.get_parent_group()
+                    if name in group.attrs:
+                        # This is an attribute (not a group), meaning that 
+                        # the object was None when deserializing it
+                        obj = None
+                    else:
+                        obj = klass()
+                        obj.deserialize(self)
+                seq.append(obj)
+        return seq
 
     read_none = read_any
