@@ -9,6 +9,8 @@
 All guidata item/group features demo
 """
 
+from __future__ import print_function
+
 SHOW = True # Show test in GUI-based test launcher
 
 import tempfile, atexit, shutil
@@ -73,9 +75,9 @@ class TestParameters(DataSet):
     choice = ChoiceItem("Single choice",
                         [(16, "first choice"), (32, "second choice"),
                          (64, "third choice")]
-                        ).set_pos(col=1,colspan=2)
+                        ).set_pos(col=1, colspan=2)
     _eg = EndGroup("A sub group")
-    floatarray = FloatArrayItem("Float array", default=np.ones( (50,5), float),
+    floatarray = FloatArrayItem("Float array", default=np.ones( (50, 5), float),
                                 format=" %.2e ").set_pos(col=1)
     g0 = BeginTabGroup("group")
     mchoice1 = MultipleChoiceItem("MC type 1",
@@ -102,7 +104,7 @@ if __name__ == "__main__":
     
     e = TestParameters()
     e.floatarray[:, 0] = np.linspace( -5, 5, 50)
-    print e
+    print(e)
     if e.edit():
-        print e
+        print(e)
     e.view()
\ No newline at end of file
