@@ -11,6 +11,8 @@ RotatedLabel test
 RotatedLabel is derived from QLabel: it provides rotated text display.
 """
 
+from __future__ import unicode_literals
+
 SHOW = True # Show test in GUI-based test launcher
 
 from guidata.qt.QtGui import QFrame, QGridLayout
@@ -25,7 +27,7 @@ class Frame(QFrame):
         angle = 0
         for row in range(7):
             for column in range(7):
-                layout.addWidget(RotatedLabel(u"Label %03d°" % angle,
+                layout.addWidget(RotatedLabel("Label %03d°" % angle,
                                               angle=angle, color=Qt.blue,
                                               bold=True),
                                  row, column, Qt.AlignCenter)
